| US.returns | R Documentation |
The dataset comprises observations of both continuously compounded and simple returns derived from the S&P 500 index, along with the difference of the Chicago Board Options Exchange Market Volatility Index (VIX). The sample period spans from January 5, 2005, to April 24, 2026.
data(US.returns)
A data frame with 5420 rows and 6 variables:
A vector indicating the date of each observation.
A numeric vector giving the S&P500 index.
A numeric vector giving the Chicago Board Options Exchange Market Volatility Index (VIX).
A numeric vector giving the continuously compounded returns.
A numeric vector giving the simple returns.
A numeric vector giving the difference VIX_{t-1}-VIX_{t-2}.
Massacci, D. (2014) A two-regime threshold model with conditional skewed student-t distributions for stock returns. Economic Modelling, 43, 9-20.
data(US.returns)
dev.new()
plot(ts(as.matrix(US.returns[,-1])))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.