| WAIC.mtar | R Documentation |
mtarThis function computes the Watanabe-Akaike or Widely Available Information Criterion (WAIC),
for objects of class mtar.
## S3 method for class 'mtar'
WAIC(...)
... |
one or several objects of the class mtar. |
A numeric matrix containing the WAIC values corresponding to each mtar object in the input.
DIC
###### Example 1: Returns of the closing prices of three financial indexes
data(returns)
fit1 <- mtar_grid(~ COLCAP + BOVESPA | SP500, data=returns, row.names=Date,
subset={Date<="2015-12-07"}, dist=c("Gaussian","Student-t",
"Slash","Laplace"), nregim.min=2, nregim.max=3, p.min=2,
p.max=2, n.burnin=1000, n.sim=2000, n.thin=2,
plan_strategy="multisession")
WAIC(fit1)
###### Example 2: Rainfall and two river flows in Colombia
data(riverflows)
fit2 <- mtar_grid(~ Bedon + LaPlata | Rainfall, data=riverflows,
row.names=Date, subset={Date<="2009-02-13"},dist="Laplace",
nregim.min=2, nregim.max=3, p.min=1, p.max=3,n.burnin=1000,
n.sim=2000, n.thin=2, plan_strategy="multisession")
WAIC(fit2)
###### Example 3: Temperature, precipitation, and two river flows in Iceland
data(iceland.rf)
fit3 <- mtar_grid(~ Jokulsa + Vatnsdalsa | Temperature | Precipitation,
data=iceland.rf,subset={Date<="1974-11-06"},row.names=Date,
dist=c("Slash","Student-t"), nregim.min=1, nregim.max=2,
p.min=15, p.max=15, q.min=4, q.max=4, d.min=2, d.max=2,
n.burnin=1000, n.sim=2000, n.thin=2,
plan_strategy="multisession")
WAIC(fit3)
###### Example 4: U.S. stock returns
data(US.returns)
fit4 <- mtar_grid(~ CCR | dVIX, data=US.returns, subset={Date<="2025-11-28"},
row.names=Date, dist=c("Laplace","Student-t","Slash"),
nregim.min=2, nregim.max=2, p.min=3, p.max=3, d.min=3,
d.max=3, n.burnin=1000, n.sim=2000, n.thin=2,
plan_strategy="multisession")
WAIC(fit4)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.