mtar objectsThis function computes Geweke's convergence diagnostic for Markov chain Monte Carlo
(MCMC) output obtained from Bayesian estimation of multivariate TAR models. It is a
wrapper around geweke.diag() that applies the diagnostic to the posterior chains
returned by a call to mtar().
geweke.diagTAR(x, frac1 = 0.1, frac2 = 0.5)A list containing the Geweke z-scores for the parameters of the mtar model.
An object of class mtar returned by the function mtar().
A numeric value in \((0,1)\) specifying the fraction of the initial part of each chain to be used in the diagnostic.
A numeric value in \((0,1)\) specifying the fraction of the final part of each chain to be used in the diagnostic.
geweke.diag