| out_of_sample.mtar | R Documentation |
Computes Out-of-Sample predictive accuracy measures for two or more objects of class mtar.
## S3 method for class 'mtar'
out_of_sample(
...,
newdata,
n.ahead = NULL,
credible = 0.95,
FUN = mean,
rolling = NULL
)
... |
one or more objects of class |
newdata |
A |
n.ahead |
A positive integer specifying the number of steps ahead to forecast. |
credible |
An optional numeric value in |
FUN |
An optional function used to summarize the |
rolling |
An optional positive integer specifying the rolling-window size used for forecasting.
By default, |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.