Computes estimates of the variance–covariance matrices for the scale parameters of a fitted multivariate TAR model.
Usage
# S3 method for class 'mtar'
vcov(object, ..., FUN = mean)Computes estimates of the variance–covariance matrices for the scale parameters of a fitted multivariate TAR model.
# S3 method for class 'mtar'
vcov(object, ..., FUN = mean)