Learn R Programming

mtarm (version 0.1.8)

vcov.mtar: vcov method for objects of class mtar

Description

Computes estimates of the variance–covariance matrices for the scale parameters of a fitted multivariate TAR model.

Usage

# S3 method for mtar
vcov(object, ..., FUN = mean)

Value

A list containing the variance–covariance estimates obtained by applying

FUN to the MCMC chains associated with the scale parameters.

Arguments

object

an object of class mtar, typically obtained from a call to mtar().

...

additional arguments passed to FUN.

FUN

a function to be applied to the MCMC chains of the scale parameters in order to obtain point estimates. By default, FUN is set to mean().