mtarComputes estimates of the variance–covariance matrices for the scale parameters of a fitted multivariate TAR model.
# S3 method for mtar
vcov(object, ..., FUN = mean)A list containing the variance–covariance estimates obtained by applying
FUN to the MCMC chains associated with the scale parameters.
an object of class mtar, typically obtained from a call to
mtar().
additional arguments passed to FUN.
a function to be applied to the MCMC chains of the scale parameters in order
to obtain point estimates. By default, FUN is set to mean().